@@ -20,7 +20,7 @@ use vars qw ($VERSION $version $outputfile $element_type $author $title
 
 $author = '';
 $title = '';
-$VERSION="v5.094";
+$VERSION="v5.095";
 $version=
   "Almost Free Text $VERSION; Copyright 1996-2004 Todd Coram. All rights reserved.";
 
@@ -68,10 +68,10 @@ my $mode =
 
 # Cache (memo) variables. Not state, but artifact used by states.
 #
-my $tableCaption = '';		# Holds current table's caption.
-my @listStack;			# A stack of lists as we nest.
-my @sectionStack;		# Keeps track of nesting sections.
-my $sectionNumber = Autonum->new();
+my $table_caption = '';		# Holds current table's caption.
+my @list_stack;			# A stack of lists as we nest.
+my @section_stack;		# Keeps track of nesting sections.
+my $section_number = Autonum->new();
 
 my @index;			# Holds running index targets. TBD
 
@@ -119,26 +119,26 @@ $AFT_OUTPUT::pragma_ctl{postfilter} = 'yes';
 # AFT functions
 #
 my @Functions = (
-	      \&handleBlockedVerbatim, # Must be before first...
-	      \&handleComments, # Must be first
-	      \&handleTitlePreamble, # Must be second
-	      \&handleIncludes,
-	      \&handleImage,
-	      \&handleRuler,
-	      \&handleSections,
-	      \&handleLists,
-	      \&handleCenteredText,
-	      \&handleQuotedText,
-	      \&handleTable,
-	      \&handleVerbatim,
+	      \&handle_blocked_verbatim, # Must be before first...
+	      \&handle_comments, # Must be first
+	      \&handle_title_preamble, # Must be second
+	      \&handle_includes,
+	      \&handle_image,
+	      \&handle_ruler,
+	      \&handle_sections,
+	      \&handle_lists,
+	      \&handle_centered_text,
+	      \&handle_quoted_text,
+	      \&handle_table,
+	      \&handle_verbatim,
 	     );
 
 
 # Run AFT from the command line. (The normal way to invoke AFT)
 #
 sub main {
-    &parseCommandLine();
-    &loadElementFile(&elementFile());
+    &parse_command_line();
+    &load_element_file(&element_file());
 
     if ($outputfile eq '') {
         # Use first input filename to construct output filename.
@@ -158,7 +158,7 @@ sub main {
     #
     print(STDERR 
       "$version\n  Writing $element_type output into $outputfile using". 
-	  " $INC{elementFile()}.\n") if $verbose;
+	  " $INC{element_file()}.\n") if $verbose;
 
 
     &begin();
@@ -166,7 +166,7 @@ sub main {
     # Process each file supplied on the command line.
     #
     foreach my $filename (@ARGV) {
-	&processFile($filename);
+	&process_file($filename);
     }
 
     &end();
@@ -174,9 +174,9 @@ sub main {
     close(OUT);
     close($tocout) if $tocout; # If we wrote a table of contents, close it.
         
-    if (my $postProcessor = $AFT_OUTPUT::elem{'PostProcessor'}) {
-	print(STDERR "\nPost Processing with '$postProcessor'\n")
-	    and eval $postProcessor
+    if (my $post_processor = $AFT_OUTPUT::elem{'PostProcessor'}) {
+	print(STDERR "\nPost Processing with '$post_processor'\n")
+	    and eval $post_processor
 	    or die "Can't post process $outputfile $!\n";
     }
 
@@ -187,7 +187,7 @@ sub main {
 sub begin {
     # Initialize our state.
     #
-    &resetStates();
+    &reset_states();
 
     # Hold onto the preamble 'til we see if *Title and *Author info is present.
     #
@@ -196,11 +196,11 @@ sub begin {
 
 # Run AFT on a file given its filename.
 #
-sub doFile {
+sub do_file {
     my($filename) = @_;
-    &loadElementFile(&elementFile());
+    &load_element_file(&element_file());
     &begin();
-    &processFile($filename);
+    &process_file($filename);
     &end();
 }
 
@@ -208,7 +208,7 @@ sub doFile {
 # Run AFT on a single line supplied as a string (with a reference filename
 # and line number-- both can be fake.)
 #
-sub doString {
+sub do_string {
     local $_ = shift;
     my ($fname, $lcnt) = @_;
     
@@ -229,16 +229,16 @@ sub doString {
     # Always reset states
     # (take us out of whatever mode we may have been in).
     #
-    &resetStates();
+    &reset_states();
     
     # Now handle a special case... We need to detect blank lines to
     # determine whether we should end paragraph mode.
     #
-    &resetParagraph(), return if $_ eq '';
+    &reset_paragraph(), return if $_ eq '';
     
     # Otherwise, if not in paragraph mode, enter paragraph mode now.
     #
-    &enterParagraph() if !$mode->{inParagraph};
+    &enter_paragraph() if !$mode->{inParagraph};
     
     # and  kick out the filtered line.
     #
@@ -247,29 +247,29 @@ sub doString {
 
 # Run AFT on a file given its file handle.
 #
-sub doFH_File {
+sub do_f_h__file {
     my($fh, $filename) = @_;
-    &loadElementFile(&elementFile());
+    &load_element_file(&element_file());
     &begin();
-    &processFH_File($fh, $filename);
+    &process_f_h__file($fh, $filename);
     &end();
 }
 
 
 sub output_preamble {
-    &output($AFT_OUTPUT::filePreamble."\n",
+    &output($AFT_OUTPUT::file_preamble."\n",
 	    title => $title, author => $author, version => $version);
 }
 
 sub output_postamble {
-    &output($AFT_OUTPUT::filePostamble."\n", aft => &filter($aft_advert));
+    &output($AFT_OUTPUT::file_postamble."\n", aft => &filter($aft_advert));
 }
 
 sub output_notes {
     &output($AFT_OUTPUT::elem{'HorizontalLine'}."\n");
     my $count = 1;
     foreach my $note (@note) {
-	&doString("=[(fNOTE$count)]=\n\\[[$count(REFfNOTE$count)]] - $note\n\\\\");
+	&do_string("=[(fNOTE$count)]=\n\\[[$count(REFfNOTE$count)]] - $note\n\\\\");
 	$count++;
     }
 }
@@ -277,11 +277,11 @@ sub output_notes {
 sub end {
     # End all modes.
     #
-    &resetStates();
+    &reset_states();
     
     # If we ever entered sections...
 
-    &enterSection(0), &output($AFT_OUTPUT::elem{'EndSectLevel1'}."\n")
+    &enter_section(0), &output($AFT_OUTPUT::elem{'EndSectLevel1'}."\n")
 	if ($mode->{haveSections});
     
     &output_notes() if ($AFT_OUTPUT::elem{'NotesAtEnd?'} eq 'yes');
@@ -291,7 +291,7 @@ sub end {
     &output_postamble();
 }
 
-sub parseCommandLine {
+sub parse_command_line {
     ## Process the command line options.
     #
     my $usage=
@@ -309,13 +309,13 @@ sub parseCommandLine {
     
 }
 
-sub elementFile {
+sub element_file {
     return "aft-".$element_type.".pm";
 }
 
 # loadElementFile(file) - load the supplied element file name.
 #
-sub loadElementFile {
+sub load_element_file {
     my $elementfile = shift;
     # This is more of an '#include' than a package import.
     eval
@@ -326,12 +326,12 @@ sub loadElementFile {
 
     # Initialize elements;
     #
-    &AFT_OUTPUT::initElements();
+    &AFT_OUTPUT::init_elements();
 }
 
 # processFile(fname) - Locate, open and process the supplied file.
 #
-sub processFile {
+sub process_file {
     my($fname) = @_;
     local *IN;
     if (!open(*IN, $fname)) {
@@ -342,7 +342,7 @@ sub processFile {
     # Do that voodoo that you do so well.
     #
     print (STDERR "\nProcessing $fname.\n[") if $verbose;
-    &processFH_File(*IN, $fname);
+    &process_f_h__file(*IN, $fname);
     
     # Done with it, so close it.
     #
@@ -354,7 +354,7 @@ sub processFile {
 
 # processFH_File (fh,fname) - Process the supplied file by the handle.
 #
-sub processFH_File {
+sub process_f_h__file {
     my($fh, $fname) = @_;
     my $lcnt  = 0;		# line count
     
@@ -363,10 +363,10 @@ sub processFH_File {
 	$lcnt++;
 	chop;
 	$continued_line .= $1, next LINE if /(.*)\\$/; # collect continuations
-	&doString($continued_line.$_, $fname, $lcnt); # process complete line
+	&do_string($continued_line.$_, $fname, $lcnt); # process complete line
 	$continued_line = "";
     }
-    &doString($continued_line, $fname, $lcnt) if $continued_line;
+    &do_string($continued_line, $fname, $lcnt) if $continued_line;
 }
 
 
@@ -376,7 +376,7 @@ sub processFH_File {
 
 # Handle comments and comment commands
 #
-sub handleComments {
+sub handle_comments {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     # Handle Strike lines (X---)
@@ -432,7 +432,7 @@ sub handleComments {
 
 # Handle *Title, *Author and preamble output.
 #
-sub handleTitlePreamble {
+sub handle_title_preamble {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     # *Title:
@@ -471,11 +471,11 @@ sub handleTitlePreamble {
 
 #  Handle *Insert:, *Include:, *File:,*See File and table of contents.
 #
-sub handleIncludes {
+sub handle_includes {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     /^\*(Insert|See File|Include|File):\s*(\S+)/ and do {
-	&processFile($2);
+	&process_file($2);
 	return 1;
     };
 
@@ -485,7 +485,7 @@ sub handleIncludes {
 	# If there is no automatic table of contents markup, then generate
 	# an AFT style markup.
 	if ($AFT_OUTPUT::elem{$1} eq '') {
-	    &generateTOC($fname);
+	    &generate_t_oC($fname);
 	} else {
 	    &output($AFT_OUTPUT::elem{$1}."\n");
 	}
@@ -496,7 +496,7 @@ sub handleIncludes {
 
 # Handle *Image: and it's variations.
 #
-sub handleImage {
+sub handle_image {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     /^\*(Image|Image-left|Image-center|Image-right):\s*(\S+)/ and do {
@@ -508,7 +508,7 @@ sub handleImage {
 
 # Handle ------
 #
-sub handleRuler {
+sub handle_ruler {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     /^\-{4,}/ and do {
@@ -522,7 +522,7 @@ sub handleRuler {
 # Handle *, **, ***, **** (sections) and
 # ^*, ^**, ^***, ^**** (sections referencing TOC)
 #
-sub handleSections {
+sub handle_sections {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     /^(\^*\*{1,4})\s*(.+?)\s*$/ and do {
@@ -531,10 +531,10 @@ sub handleSections {
 	    &output($AFT_OUTPUT::elem{'BeginSectLevel1'}."\n");
 	    $mode->{haveSections} = 1;
 	}
-	&enterSection(length $1);
+	&enter_section(length $1);
 
-	$sectionNumber->incr(length $1);
-	my $number = $sectionNumber->dotted();
+	$section_number->incr(length $1);
+	my $number = $section_number->dotted();
 	my $full_sname = $sname;
 	$full_sname = "$number. $sname" if $autonumber;
 	
@@ -558,7 +558,7 @@ sub handleSections {
 
 # List Mode
 #
-sub handleLists {
+sub handle_lists {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     # Only do this if not in verbatim/quote mode and we parse one of the 
@@ -575,62 +575,62 @@ sub handleLists {
 	 my $rest_of_line = $3;
 	 my $list = '';
 	 my ($le, $name);
-	 my $newLevel = length($1);
-	 my $curListLevel = scalar @listStack;
-	 my $currentList = '';
+	 my $new_level = length($1);
+	 my $cur_list_level = scalar @list_stack;
+	 my $current_list = '';
 	 
-	 if ($curListLevel gt 0) {
-	     $currentList = $listStack[$#listStack];
+	 if ($cur_list_level gt 0) {
+	     $current_list = $list_stack[$#list_stack];
 	 }
 	 
 	 if ($2 =~ /^\*/) {
 	     $list = 'Bullet';
-	     $le = &prepareOutput($AFT_OUTPUT::elem{'BulletListElement'});
+	     $le = &prepare_output($AFT_OUTPUT::elem{'BulletListElement'});
 	 } elsif ($2 =~ /^\[(.+)\]/) {
 	     $name = $1,
 	     $list = 'Named',
-	     $le = &prepareOutput($AFT_OUTPUT::elem{'NamedListElement'}, 
+	     $le = &prepare_output($AFT_OUTPUT::elem{'NamedListElement'}, 
 				  name => &filter($name));
 	 } else {
 	     $list = 'Numbered';
-	     $le = &prepareOutput($AFT_OUTPUT::elem{'NumberedListElement'});
+	     $le = &prepare_output($AFT_OUTPUT::elem{'NumberedListElement'});
 	 }
 	 # Are we nesting yet?
 	 #
-	 while ($curListLevel < $newLevel) {
+	 while ($cur_list_level < $new_level) {
 	     # Increase nest level
 	     #
-	     push(@listStack,$list);
-	     &endListElement();
+	     push(@list_stack,$list);
+	     &end_list_element();
 	     &output($AFT_OUTPUT::elem{'Start'.$list.'List'}."\n");
 	     
-	     $curListLevel++;
-	     $currentList = $list;
+	     $cur_list_level++;
+	     $current_list = $list;
 	 } 
-	 while ($curListLevel > $newLevel) {
+	 while ($cur_list_level > $new_level) {
 	     # Retreat to a previous level
 	     #
-	     &endListElement();
-	     $currentList = pop(@listStack);
+	     &end_list_element();
+	     $current_list = pop(@list_stack);
 	     
-	     &output($AFT_OUTPUT::elem{'End'.$currentList.'List'}."\n");
+	     &output($AFT_OUTPUT::elem{'End'.$current_list.'List'}."\n");
 	     
-	     $curListLevel--;
-	     $currentList = pop(@listStack);
-	     push(@listStack, $currentList);
+	     $cur_list_level--;
+	     $current_list = pop(@list_stack);
+	     push(@list_stack, $current_list);
 	 }
-	 if ($list ne $currentList) {
+	 if ($list ne $current_list) {
 	     # Changing horses... A new list type.
 	     #
-	     &endListElement();
-	     $currentList = pop(@listStack);
+	     &end_list_element();
+	     $current_list = pop(@list_stack);
 	     
-	     &output($AFT_OUTPUT::elem{'End'.$currentList.'List'}."\n");
-	     push(@listStack,$list);
-	     $currentList = $list;
+	     &output($AFT_OUTPUT::elem{'End'.$current_list.'List'}."\n");
+	     push(@list_stack,$list);
+	     $current_list = $list;
 	     &output($AFT_OUTPUT::elem{'Start'.$list.'List'}."\n");
 	 }
-	 &endListElement();
+	 &end_list_element();
 	 
 	 $mode->{inListElement} = 1;
 	 &output($le);		# output element line
@@ -640,20 +640,20 @@ sub handleLists {
     
     # Print a continuation of list element if in list mode and tabbed...
     #
-    if (scalar(@listStack) and /^\t\s*(.*)$/) {
+    if (scalar(@list_stack) and /^\t\s*(.*)$/) {
 	&output(' '.&filter($1));
 	return 1;
     }
 
-  &endListElement();
+  &end_list_element();
   return 0;
 }
 
 # Terminate list element.
 #
-sub endListElement {
+sub end_list_element {
     if ($mode->{inListElement}) {
-	&output($AFT_OUTPUT::elem{'End'.$listStack[$#listStack].
+	&output($AFT_OUTPUT::elem{'End'.$list_stack[$#list_stack].
 				      'ListElement'}."\n");
 	$mode->{inListElement} = 0;
     }
@@ -661,12 +661,12 @@ sub endListElement {
 
 # Handle centered text.
 #
-sub handleCenteredText {
+sub handle_centered_text {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
-    (!scalar(@listStack) and !$mode->{inVerbatim} and 
+    (!scalar(@list_stack) and !$mode->{inVerbatim} and 
      !$mode->{inQuote} and /^\t{2,}(.*)$/) and do {
-	 &resetStates();	
+	 &reset_states();	
 	 &output($AFT_OUTPUT::elem{'Center'}."\n", center => &filter($1));
 	 return 1;
      };
@@ -676,12 +676,12 @@ sub handleCenteredText {
 
 # Handle quoted text.
 #
-sub handleQuotedText {
+sub handle_quoted_text {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     (!$mode->{inVerbatim} and /^\t\#\s*(.*)$/) and do {
 	if (!$mode->{inQuote}) { # if we aren't in quote mode yet...
-	    &resetStates();
+	    &reset_states();
 	    &output($AFT_OUTPUT::elem{'StartQuote'}."\n");
 	    $mode->{inQuote} = 1;
 	}
@@ -693,11 +693,11 @@ sub handleQuotedText {
 
 # Handle tables
 #
-sub handleTable {
+sub handle_table {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
 
     if ($AFT_OUTPUT::pragma_ctl{tableparser} eq 'new') {
-	return &handleNewTableParser($fname, $lcnt, $_);
+	return &handle_new_table_parser($fname, $lcnt, $_);
     }
     # If not in verbatim or quote mode, try table...
     #
@@ -709,7 +709,7 @@ sub handleTable {
 	# First thing is first... Are we in the table yet?
 	#
 	!$mode->{inTable} and do {
-	    &resetStates();		# start clean
+	    &reset_states();		# start clean
 	    $mode->{inTable} = 1;
 	    
 	    # Don't really start the table yet. We need to know how many
@@ -720,7 +720,7 @@ sub handleTable {
 	    $1 =~ /([^\!]*)/;
 	    # The first thing we got was a caption. Save it for later.
 	    #
-	    $tableCaption = &filter($1);
+	    $table_caption = &filter($1);
 	    return 1;
 	};
 
@@ -750,9 +750,9 @@ sub handleTable {
 	    #
 	    
 	    &output($AFT_OUTPUT::elem{'StartTable'}."\n", columns =>$ecnt,
-		   caption => $tableCaption);
+		   caption => $table_caption);
 	    &output($AFT_OUTPUT::elem{'TableCaption'}."\n", 
-		    caption => $tableCaption);
+		    caption => $table_caption);
 	    $mode->{needTableHeaders} = 0;	# don't need them anymore
 	    $ftype = $AFT_OUTPUT::elem{'TableHeader'}; # short hand 
 	} else {
@@ -777,7 +777,7 @@ sub handleTable {
 # Handle ''New Style'' tables
 #
 my @row_acc;
-sub handleNewTableParser {
+sub handle_new_table_parser {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     # If not in verbatim or quote mode, try table...
@@ -792,7 +792,7 @@ sub handleNewTableParser {
 	# First thing is first... Are we in the table yet?
 	#
 	!$mode->{inTable} and do {
-	    &resetStates();		# start clean
+	    &reset_states();		# start clean
 	    $mode->{inTable} = 1;
 	    
 	    # Don't really start the table yet. We need to know how many
@@ -803,7 +803,7 @@ sub handleNewTableParser {
 	    if ($1 =~ /([^\!]*)/) { $tline = $1; }
 	    # The first thing we got was a caption. Save it for later.
 	    #
-	    $tableCaption = &filter($tline);
+	    $table_caption = &filter($tline);
 	    $mode->{eatOne} = 1;
 	    return 1;
 	};
@@ -855,9 +855,9 @@ sub handleNewTableParser {
 	    # problem.
 	    #
 	    &output($AFT_OUTPUT::elem{'StartTable'}."\n", columns =>$ecnt, 
-		    caption => $tableCaption);
+		    caption => $table_caption);
 	    &output($AFT_OUTPUT::elem{'TableCaption'}."\n", 
-		    caption => $tableCaption);
+		    caption => $table_caption);
 	}
 
 	# If just accumulating...
@@ -876,23 +876,23 @@ sub handleNewTableParser {
     
 # Handle verbatim issues.
 #
-sub handleBlockedVerbatim {
+sub handle_blocked_verbatim {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     if ($mode->{blockedVerbatim} or $mode->{filteredVerbatim}) {
-	&handleVerbatim($fname,$lcnt,$_);
+	&handle_verbatim($fname,$lcnt,$_);
 	return 1;
     }
     return  0;			# drop thru
 }
 
-sub handleVerbatim {
+sub handle_verbatim {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     # Check to see if we should get out of blocked/filtered verbatim mode.
     #
     /^\^>>/ and do {
 	# Get out of blocked and filtered verbatim mode
-	&resetStates();
+	&reset_states();
 	return 1;
     };
     
@@ -903,7 +903,7 @@ sub handleVerbatim {
 	 # First, are we starting fresh?
 	 #
 	 (!$mode->{inVerbatim} and !$mode->{inQuote}) and do {
-	     &resetStates();		# start clean
+	     &reset_states();		# start clean
 	     $mode->{inVerbatim} = 1;
 
 	     # We are just entering the blocked verbatim mode, 
@@ -958,7 +958,7 @@ sub handleVerbatim {
 
 # Generate and possibly include a table of contents file.
 #
-sub generateTOC {
+sub generate_t_oC {
     # Try and open a table of contents file
     #
     my ($fname) = @_;
@@ -969,7 +969,7 @@ sub generateTOC {
 	# Read it in.
 	#
 	print (STDERR "\t Reading table of contents from $tocfile...")if $verbose;
-	&processFH_File(*TOCIN, $tocfile);
+	&process_f_h__file(*TOCIN, $tocfile);
 	close(TOCIN);
 	&output("\n\n");
 	print (STDERR "Done.\n") if $verbose;
@@ -1004,7 +1004,7 @@ sub filter {
     if ($AFT_OUTPUT::pragma_ctl{prefilter} eq 'yes') {
 	$line =  &AFT_OUTPUT::prefilter($line);
 	
-	# First, protect ||, \|,  __, \_,  ~~ and \~ 
+	# First, protect ||, \|,  __, \_,  \\, ~~ and \~ 
 	# 
 	$line =~ s/__|\\_/%UnDeRLiNE%/g;
 	$line =~ s/\|\||\\\|/%PiPe%/g;
@@ -1036,7 +1036,7 @@ sub filter {
 	    $line =~ s/$fc$/$AFT_OUTPUT::elem{"End$fcn"}/;
 	};
 	
-	# Now fix _ ~ and |   - 19sep96
+	# Now fix _ ~, \  and |
 	# 
 	$line =~ s/%UnDeRLiNE%/_/g;
 	$line =~ s/%PiPe%/\|/g;
@@ -1047,11 +1047,11 @@ sub filter {
 
     # Handle footnote references
     #
-    $line = &handleNotes($line);
+    $line = &handle_notes($line);
 
     # Handle hyper links
     #
-    $line = &handleLinks($line);
+    $line = &handle_links($line);
     
     
     # Post-filter now. Pass its return up to the caller of filter().
@@ -1060,15 +1060,15 @@ sub filter {
 }
 
 
-sub handleNotes {
+sub handle_notes {
     my($line) = @_;
 
     my $notenum = scalar(@note)+1;
     # look for (and replace) [Note: .. ]
     #
     $line =~ s/\[Note:\s*(.*)\]/
-	&handleLinks("=[(REFfNOTE".$notenum.")]=").
-	&prepareOutput($AFT_OUTPUT::elem{'Note'}, 
+	&handle_links("=[(REFfNOTE".$notenum.")]=").
+	&prepare_output($AFT_OUTPUT::elem{'Note'}, 
 		       note => "$1",
 		       notereftxt => $notenum,
 		       notetarget => "fNOTE$notenum")/eg
@@ -1078,14 +1078,14 @@ sub handleNotes {
 
 # Handle the various types of links we can regex.
 #
-sub handleLinks {
+sub handle_links {
     my($line) = @_;
     
     if ($AFT_OUTPUT::pragma_ctl{verbatimsquarebrackets} eq 'no') {
 	# new =[(target)]= style
 	#
 	$line =~ s/=\[\(([^\[]+?)\)\]=/
-	    &prepareOutput($AFT_OUTPUT::elem{'Target'},
+	    &prepare_output($AFT_OUTPUT::elem{'Target'},
 			   target => "$1", 
 			   text => $AFT_OUTPUT::elem{'NBSPACE'})/eg
 			   and push(@index, $1); # save for index
@@ -1093,32 +1093,32 @@ sub handleLinks {
 	# new =[target]= style
 	#
 	$line =~ s/=\[([^\]]+?)\]=/
-	    &prepareOutput($AFT_OUTPUT::elem{'Target'},
+	    &prepare_output($AFT_OUTPUT::elem{'Target'},
 			   target => "$1", text => "$1")/eg
 			   and push(@index, $1); # save for index
 	
 	# new [name (url:reference)] style
 	#
 	$line =~ s/([^\\]|^)\[([^\[]+?)\s*\(((http?|file|ftp|mailto):.+?)\)\]/
-	    $1.&prepareOutput($AFT_OUTPUT::elem{'URL'},
+	    $1.&prepare_output($AFT_OUTPUT::elem{'URL'},
 			      target => "$3", text => "$2", _text=>"$2")/eg;
 	
 	# new [name (:reference)] style (don't capture the : )
 	#
 	$line =~ s/([^\\]|^)\[([^\[]+?)\s*\(:(.+?)\)\]/
-	    $1.&prepareOutput($AFT_OUTPUT::elem{'URL'},
+	    $1.&prepare_output($AFT_OUTPUT::elem{'URL'},
 			      target => "$3", text => "$2", _text=>"$2")/eg;
 	
 	# new [name (reference)] style
 	#
 	$line =~ s/([^\\]|^)\[([^\[]+?)\s*\((.+?)\)\]/
-	    $1.&prepareOutput($AFT_OUTPUT::elem{'InternalReference'},
+	    $1.&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 			      target => "$3", text => "$2")/eg;
 	
 	# new [reference] style
 	#
 	$line =~ s/([^\\]|^)\[([^\[]+?)\]/
-	    $1.&prepareOutput($AFT_OUTPUT::elem{'InternalReference'},
+	    $1.&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 			      target => "$2", text => "$2")/eg;
 	
 	$line =~ s/\\\[/"\["/eg;
@@ -1144,46 +1144,46 @@ sub handleLinks {
     # generally any character not listed in $_seg
     #
     $line =~ s/(^|[\s\(])($AFT::httpaddr)/
-	"$1".(&prepareOutput($AFT_OUTPUT::elem{'URL'},
+	"$1".(&prepare_output($AFT_OUTPUT::elem{'URL'},
 			     target => "$2", text => "$2", 
 			     _text=>"")."$3")/eg;
     
     
     # Handle old AFT style Links
     $line =~ s/{\+((http|https|file|ftp|mailto)\:[^{}]+)\+}/
-	&prepareOutput($AFT_OUTPUT::elem{'URL'},target => "$1", text => "$1", 
+	&prepare_output($AFT_OUTPUT::elem{'URL'},target => "$1", text => "$1", 
 		       _text=>"")/eg;
     
     $line =~ s/{\-([^\@{}]+)[\@]((http|https|file|ftp|mailto)\:[^{}]+)\-}/
-	&prepareOutput($AFT_OUTPUT::elem{'URL'},target => "$2", text => "$1",
+	&prepare_output($AFT_OUTPUT::elem{'URL'},target => "$2", text => "$1",
 		       _text=>"$1")/eg;
     
     $line =~ s/\{\+\:([^{}]+)\+}/
-	&prepareOutput($AFT_OUTPUT::elem{'URL'},target => "$1", text => "$1",
+	&prepare_output($AFT_OUTPUT::elem{'URL'},target => "$1", text => "$1",
 		       _text=>"")/eg;
     
     $line =~ s/{\-([^\@{}]+)[\@]\:([^{}]+)\-}/
-	&prepareOutput($AFT_OUTPUT::elem{'URL'},target => "$2", text => "$1",
+	&prepare_output($AFT_OUTPUT::elem{'URL'},target => "$2", text => "$1",
 		       _text=>"$1")/eg;
     
     $line =~ s/\{\+([^{}]+)\+}/
-	&prepareOutput($AFT_OUTPUT::elem{'InternalReference'},
+	&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 		       target => "$1", text => "$1")/eg;
     
     $line =~ s/{\-([^\@{}]+)\-}/
-	&prepareOutput($AFT_OUTPUT::elem{'InternalReference'},
+	&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 		       target => "$1", text => "$1")/eg;
     
     $line =~ s/{\-([^\@{}]+)[\@]([^{}]+)\-}/
-	&prepareOutput($AFT_OUTPUT::elem{'InternalReference'},
+	&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 		       target => "$2", text => "$1")/eg;
     
     $line =~ s/\}\+([^{}]+)\+\{/
-	&prepareOutput($AFT_OUTPUT::elem{'Target'},
+	&prepare_output($AFT_OUTPUT::elem{'Target'},
 		       target => "$1", text => "$1")/eg;
     
     $line =~ s/\}\-([^{}]+)\-\{/
-	&prepareOutput($AFT_OUTPUT::elem{'Target'},
+	&prepare_output($AFT_OUTPUT::elem{'Target'},
 		       target => "$1", text =>$AFT_OUTPUT::elem{'NBSPACE'})/eg;
     
     return $line;
@@ -1191,14 +1191,14 @@ sub handleLinks {
 
 # enterParagraph () - enter paragraph mode.
 #
-sub enterParagraph {
+sub enter_paragraph {
     $mode->{inParagraph} = 1;
     &output($AFT_OUTPUT::elem{'StartParagraph'}."\n");
 }
 
 # resetParagraph () - reset paragraph mode.
 #
-sub resetParagraph {
+sub reset_paragraph {
     print (STDERR ".") if $verbose;
     &output($AFT_OUTPUT::elem{'EndSmall'}."\n") if $paragraph->{small};
     &output($AFT_OUTPUT::elem{'EndStrong'}."\n") if $paragraph->{strong};
@@ -1222,7 +1222,7 @@ sub resetParagraph {
 #  **** Section
 #  * Section
 #
-sub enterSection {
+sub enter_section {
     
     BEGIN {
 	# These keys are new. Don't choke if they don't exist. Don't
@@ -1239,13 +1239,13 @@ sub enterSection {
     }
     
     my ($newsectlevel) = @_;
-    &resetParagraph();
+    &reset_paragraph();
     
     # Do the section and section "level" mode popping...
     #
     if ($mode->{currentSectionLevel} ge $newsectlevel) {
-	while (@sectionStack gt 0 and $sectionStack[-1] ge $newsectlevel) {
-	    $mode->{currentSectionLevel} = pop(@sectionStack);
+	while (@section_stack gt 0 and $section_stack[-1] ge $newsectlevel) {
+	    $mode->{currentSectionLevel} = pop(@section_stack);
 	    &output($AFT_OUTPUT::elem{'EndSect'.$mode->{currentSectionLevel}}."\n");
 	    if ($mode->{currentSectionLevel} gt 3 and $newsectlevel le 3) {
 		&output($AFT_OUTPUT::elem{'EndSectLevel4'}."\n");
@@ -1267,13 +1267,13 @@ sub enterSection {
 	&output($AFT_OUTPUT::elem{'BeginSectLevel2'}."\n");
     }
     $mode->{currentSectionLevel} = $newsectlevel;
-    push(@sectionStack, $newsectlevel);
+    push(@section_stack, $newsectlevel);
 }
 
 # resetStates () - reset our state to near-normal (paragraph mode is not
 # 	affected by this subroutine).
 #
-sub resetStates {
+sub reset_states {
     # Are we in the middle of a table?
     #
     $mode->{inTable} and (!$mode->{needTableHeaders} and 
@@ -1291,8 +1291,8 @@ sub resetStates {
       &output($AFT_OUTPUT::elem{'EndQuote'}."\n"), last MODE
 	  if $mode->{inQuote};
       
-      &endListElement();
-      while (my $list = pop(@listStack)) {
+      &end_list_element();
+      while (my $list = pop(@list_stack)) {
 	  &output($AFT_OUTPUT::elem{'End'.$list.'List'}."\n");
       }
   }
@@ -1319,7 +1319,7 @@ sub set_prevar {
 # %key% is replaced by value everywhere in text.
 #
 sub output {
-    print &prepareOutput(@_);
+    print &prepare_output(@_);
 }
 
 # Prepare a line of text for output.
@@ -1328,7 +1328,7 @@ sub output {
 #
 # %key% is replaced by value everywhere in text.
 #
-sub prepareOutput {
+sub prepare_output {
     my $str = shift;
     my ($var, $val);
     
